@@ -6,9 +6,12 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthority",
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
+    "AWS::APS::AnomalyDetector",
+    "AWS::APS::ResourcePolicy",
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
     "AWS::APS::Workspace",
+    "AWS::ARCRegionSwitch::Plan",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration",
     "AWS::AccessAnalyzer::Analyzer",
@@ -82,6 +85,7 @@ types: list[str] = [
     "AWS::ApplicationAutoScaling::ScalingPolicy",
     "AWS::ApplicationInsights::Application",
     "AWS::ApplicationSignals::Discovery",
+    "AWS::ApplicationSignals::GroupingConfiguration",
     "AWS::ApplicationSignals::ServiceLevelObjective",
     "AWS::Athena::DataCatalog",
     "AWS::Athena::NamedQuery",
@@ -106,8 +110,10 @@ types: list[str] = [
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
+    "AWS::Batch::ServiceEnvironment",
     "AWS::Bedrock::Agent",
     "AWS::Bedrock::AgentAlias",
+    "AWS::Bedrock::ApplicationInferenceProfile",
     "AWS::Bedrock::DataSource",
     "AWS::Bedrock::Flow",
     "AWS::Bedrock::FlowAlias",
@@ -143,6 +149,7 @@ types: list[str] = [
     "AWS::CloudFront::AnycastIpList",
     "AWS::CloudFront::CachePolicy",
     "AWS::CloudFront::CloudFrontOriginAccessIdentity",
+    "AWS::CloudFront::ConnectionFunction",
     "AWS::CloudFront::ConnectionGroup",
     "AWS::CloudFront::ContinuousDeploymentPolicy",
     "AWS::CloudFront::Distribution",
@@ -156,6 +163,7 @@ types: list[str] = [
     "AWS::CloudFront::PublicKey",
     "AWS::CloudFront::RealtimeLogConfig",
     "AWS::CloudFront::ResponseHeadersPolicy",
+    "AWS::CloudFront::TrustStore",
     "AWS::CloudFront::VpcOrigin",
     "AWS::CloudTrail::Dashboard",
     "AWS::CloudTrail::EventDataStore",
@@ -223,6 +231,21 @@ types: list[str] = [
     "AWS::DataSync::LocationS3",
     "AWS::DataSync::LocationSMB",
     "AWS::DataSync::Task",
+    "AWS::DataZone::DataSource",
+    "AWS::DataZone::Domain",
+    "AWS::DataZone::DomainUnit",
+    "AWS::DataZone::Environment",
+    "AWS::DataZone::EnvironmentActions",
+    "AWS::DataZone::EnvironmentBlueprintConfiguration",
+    "AWS::DataZone::EnvironmentProfile",
+    "AWS::DataZone::FormType",
+    "AWS::DataZone::GroupProfile",
+    "AWS::DataZone::Owner",
+    "AWS::DataZone::PolicyGrant",
+    "AWS::DataZone::Project",
+    "AWS::DataZone::ProjectMembership",
+    "AWS::DataZone::SubscriptionTarget",
+    "AWS::DataZone::UserProfile",
     "AWS::DirectoryService::MicrosoftAD",
     "AWS::DirectoryService::SimpleAD",
     "AWS::DynamoDB::GlobalTable",
@@ -252,11 +275,16 @@ types: list[str] = [
     "AWS::EC2::Instance",
     "AWS::EC2::InstanceConnectEndpoint",
     "AWS::EC2::InternetGateway",
+    "AWS::EC2::IpPoolRouteTableAssociation",
     "AWS::EC2::KeyPair",
     "AWS::EC2::LaunchTemplate",
     "AWS::EC2::NatGateway",
     "AWS::EC2::NetworkAcl",
     "AWS::EC2::NetworkAclEntry",
+    "AWS::EC2::NetworkInsightsAccessScope",
+    "AWS::EC2::NetworkInsightsAccessScopeAnalysis",
+    "AWS::EC2::NetworkInsightsAnalysis",
+    "AWS::EC2::NetworkInsightsPath",
     "AWS::EC2::NetworkInterface",
     "AWS::EC2::NetworkInterfaceAttachment",
     "AWS::EC2::NetworkInterfacePermission",
@@ -282,6 +310,9 @@ types: list[str] = [
     "AWS::EC2::TransitGateway",
     "AWS::EC2::TransitGatewayAttachment",
     "AWS::EC2::TransitGatewayConnect",
+    "AWS::EC2::TransitGatewayConnectPeer",
+    "AWS::EC2::TransitGatewayMeteringPolicy",
+    "AWS::EC2::TransitGatewayMeteringPolicyEntry",
     "AWS::EC2::TransitGatewayMulticastDomain",
     "AWS::EC2::TransitGatewayMulticastDomainAssociation",
     "AWS::EC2::TransitGatewayMulticastGroupMember",
@@ -297,12 +328,14 @@ types: list[str] = [
     "AWS::EC2::VPCBlockPublicAccessOptions",
     "AWS::EC2::VPCCidrBlock",
     "AWS::EC2::VPCDHCPOptionsAssociation",
+    "AWS::EC2::VPCEncryptionControl",
     "AWS::EC2::VPCEndpoint",
     "AWS::EC2::VPCEndpointConnectionNotification",
     "AWS::EC2::VPCEndpointService",
     "AWS::EC2::VPCEndpointServicePermissions",
     "AWS::EC2::VPCGatewayAttachment",
     "AWS::EC2::VPCPeeringConnection",
+    "AWS::EC2::VPNConcentrator",
     "AWS::EC2::VPNConnection",
     "AWS::EC2::VPNConnectionRoute",
     "AWS::EC2::VPNGateway",
@@ -310,6 +343,7 @@ types: list[str] = [
     "AWS::EC2::Volume",
     "AWS::EC2::VolumeAttachment",
     "AWS::ECR::PullThroughCacheRule",
+    "AWS::ECR::PullTimeUpdateExclusion",
     "AWS::ECR::RegistryPolicy",
     "AWS::ECR::RegistryScanningConfiguration",
     "AWS::ECR::ReplicationConfiguration",
@@ -318,6 +352,7 @@ types: list[str] = [
     "AWS::ECS::CapacityProvider",
     "AWS::ECS::Cluster",
     "AWS::ECS::ClusterCapacityProviderAssociations",
+    "AWS::ECS::ExpressGatewayService",
     "AWS::ECS::PrimaryTaskSet",
     "AWS::ECS::Service",
     "AWS::ECS::TaskDefinition",
@@ -327,6 +362,7 @@ types: list[str] = [
     "AWS::EFS::MountTarget",
     "AWS::EKS::AccessEntry",
     "AWS::EKS::Addon",
+    "AWS::EKS::Capability",
     "AWS::EKS::Cluster",
     "AWS::EKS::FargateProfile",
     "AWS::EKS::IdentityProviderConfig",
@@ -340,6 +376,7 @@ types: list[str] = [
     "AWS::EMR::Studio",
     "AWS::EMR::StudioSessionMapping",
     "AWS::EMRContainers::VirtualCluster",
+    "AWS::EMRServerless::Application",
     "AWS::ElastiCache::CacheCluster",
     "AWS::ElastiCache::GlobalReplicationGroup",
     "AWS::ElastiCache::ParameterGroup",
@@ -373,6 +410,8 @@ types: list[str] = [
     "AWS::Events::EventBus",
     "AWS::Events::EventBusPolicy",
     "AWS::Events::Rule",
+    "AWS::FIS::ExperimentTemplate",
+    "AWS::FIS::TargetAccountConfiguration",
     "AWS::FMS::NotificationChannel",
     "AWS::FMS::Policy",
     "AWS::FMS::ResourceSet",
@@ -411,7 +450,9 @@ types: list[str] = [
     "AWS::GuardDuty::Master",
     "AWS::GuardDuty::Member",
     "AWS::GuardDuty::PublishingDestination",
+    "AWS::GuardDuty::ThreatEntitySet",
     "AWS::GuardDuty::ThreatIntelSet",
+    "AWS::GuardDuty::TrustedEntitySet",
     "AWS::IAM::AccessKey",
     "AWS::IAM::Group",
     "AWS::IAM::GroupPolicy",
@@ -450,6 +491,9 @@ types: list[str] = [
     "AWS::KMS::Alias",
     "AWS::KMS::Key",
     "AWS::KMS::ReplicaKey",
+    "AWS::KafkaConnect::Connector",
+    "AWS::KafkaConnect::CustomPlugin",
+    "AWS::KafkaConnect::WorkerConfiguration",
     "AWS::Kinesis::ResourcePolicy",
     "AWS::Kinesis::Stream",
     "AWS::Kinesis::StreamConsumer",
@@ -520,6 +564,7 @@ types: list[str] = [
     "AWS::OpenSearchServerless::SecurityConfig",
     "AWS::OpenSearchServerless::SecurityPolicy",
     "AWS::OpenSearchServerless::VpcEndpoint",
+    "AWS::OpenSearchService::Application",
     "AWS::OpenSearchService::Domain",
     "AWS::OpsWorks::App",
     "AWS::OpsWorks::ElasticLoadBalancerAttachment",
@@ -562,6 +607,7 @@ types: list[str] = [
     "AWS::RDS::DBProxyTargetGroup",
     "AWS::RDS::DBSecurityGroup",
     "AWS::RDS::DBSecurityGroupIngress",
+    "AWS::RDS::DBShardGroup",
     "AWS::RDS::DBSubnetGroup",
     "AWS::RDS::EventSubscription",
     "AWS::RDS::GlobalCluster",
@@ -621,9 +667,34 @@ types: list[str] = [
     "AWS::S3ObjectLambda::AccessPoint",
     "AWS::S3ObjectLambda::AccessPointPolicy",
     "AWS::S3Tables::Namespace",
+    "AWS::S3Tables::Table",
     "AWS::S3Tables::TableBucket",
     "AWS::S3Tables::TableBucketPolicy",
+    "AWS::S3Tables::TablePolicy",
     "AWS::SDB::Domain",
+    "AWS::SES::ConfigurationSet",
+    "AWS::SES::ConfigurationSetEventDestination",
+    "AWS::SES::ContactList",
+    "AWS::SES::DedicatedIpPool",
+    "AWS::SES::EmailIdentity",
+    "AWS::SES::MailManagerAddonInstance",
+    "AWS::SES::MailManagerAddonSubscription",
+    "AWS::SES::MailManagerAddressList",
+    "AWS::SES::MailManagerArchive",
+    "AWS::SES::MailManagerIngressPoint",
+    "AWS::SES::MailManagerRelay",
+    "AWS::SES::MailManagerRuleSet",
+    "AWS::SES::MailManagerTrafficPolicy",
+    "AWS::SES::MultiRegionEndpoint",
+    "AWS::SES::Template",
+    "AWS::SES::VdmAttributes",
+    "AWS::SMSVOICE::ConfigurationSet",
+    "AWS::SMSVOICE::OptOutList",
+    "AWS::SMSVOICE::PhoneNumber",
+    "AWS::SMSVOICE::Pool",
+    "AWS::SMSVOICE::ProtectConfiguration",
+    "AWS::SMSVOICE::ResourcePolicy",
+    "AWS::SMSVOICE::SenderId",
     "AWS::SNS::Subscription",
     "AWS::SNS::Topic",
     "AWS::SNS::TopicInlinePolicy",
@@ -655,6 +726,7 @@ types: list[str] = [
     "AWS::SageMaker::ModelPackage",
     "AWS::SageMaker::ModelPackageGroup",
     "AWS::SageMaker::Pipeline",
+    "AWS::SageMaker::ProcessingJob",
     "AWS::SageMaker::Space",
     "AWS::SageMaker::StudioLifecycleConfig",
     "AWS::SageMaker::UserProfile",
@@ -721,6 +793,7 @@ types: list[str] = [
     "AWS::VerifiedPermissions::PolicyTemplate",
     "AWS::VpcLattice::AccessLogSubscription",
     "AWS::VpcLattice::AuthPolicy",
+    "AWS::VpcLattice::DomainVerification",
     "AWS::VpcLattice::Listener",
     "AWS::VpcLattice::ResourcePolicy",
     "AWS::VpcLattice::Rule",
@@ -760,6 +833,7 @@ cached: list[str] = [
     "aws-acmpca-permission.json",
     "aws-amazonmq-broker.json",
     "aws-amazonmq-configuration.json",
+    "aws-amazonmq-configurationassociation.json",
     "aws-apigateway-account.json",
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
@@ -808,6 +882,7 @@ cached: list[str] = [
     "aws-applicationautoscaling-scalingpolicy.json",
     "aws-applicationinsights-application.json",
     "aws-applicationsignals-discovery.json",
+    "aws-applicationsignals-groupingconfiguration.json",
     "aws-applicationsignals-servicelevelobjective.json",
     "aws-appmesh-gatewayroute.json",
     "aws-appmesh-mesh.json",
@@ -827,15 +902,17 @@ cached: list[str] = [
     "aws-appsync-graphqlschema.json",
     "aws-appsync-resolver.json",
     "aws-appsync-sourceapiassociation.json",
+    "aws-aps-anomalydetector.json",
+    "aws-aps-resourcepolicy.json",
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
     "aws-aps-workspace.json",
+    "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-datacatalog.json",
     "aws-athena-namedquery.json",
     "aws-athena-preparedstatement.json",
-    "aws-athena-workgroup.json",
     "aws-autoscaling-autoscalinggroup.json",
     "aws-autoscaling-launchconfiguration.json",
     "aws-autoscaling-lifecyclehook.json",
@@ -855,13 +932,14 @@ cached: list[str] = [
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
+    "aws-batch-serviceenvironment.json",
     "aws-bedrock-agent.json",
     "aws-bedrock-agentalias.json",
+    "aws-bedrock-applicationinferenceprofile.json",
     "aws-bedrock-datasource.json",
     "aws-bedrock-flow.json",
     "aws-bedrock-flowalias.json",
     "aws-bedrock-flowversion.json",
-    "aws-bedrock-guardrail.json",
     "aws-bedrock-guardrailversion.json",
     "aws-bedrock-knowledgebase.json",
     "aws-bedrock-prompt.json",
@@ -869,6 +947,7 @@ cached: list[str] = [
     "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
     "aws-certificatemanager-certificate.json",
+    "aws-chatbot-customaction.json",
     "aws-chatbot-microsoftteamschannelconfiguration.json",
     "aws-chatbot-slackchannelconfiguration.json",
     "aws-cloudformation-customresource.json",
@@ -889,8 +968,10 @@ cached: list[str] = [
     "aws-cloudfront-anycastiplist.json",
     "aws-cloudfront-cachepolicy.json",
     "aws-cloudfront-cloudfrontoriginaccessidentity.json",
+    "aws-cloudfront-connectionfunction.json",
     "aws-cloudfront-connectiongroup.json",
     "aws-cloudfront-continuousdeploymentpolicy.json",
+    "aws-cloudfront-distribution.json",
     "aws-cloudfront-distributiontenant.json",
     "aws-cloudfront-function.json",
     "aws-cloudfront-keygroup.json",
@@ -901,8 +982,10 @@ cached: list[str] = [
     "aws-cloudfront-publickey.json",
     "aws-cloudfront-realtimelogconfig.json",
     "aws-cloudfront-responseheaderspolicy.json",
+    "aws-cloudfront-truststore.json",
     "aws-cloudfront-vpcorigin.json",
     "aws-cloudtrail-dashboard.json",
+    "aws-cloudtrail-eventdatastore.json",
     "aws-cloudtrail-resourcepolicy.json",
     "aws-cloudtrail-trail.json",
     "aws-cloudwatch-alarm.json",
@@ -917,6 +1000,7 @@ cached: list[str] = [
     "aws-codedeploy-application.json",
     "aws-codedeploy-deploymentconfig.json",
     "aws-codedeploy-deploymentgroup.json",
+    "aws-codepipeline-customactiontype.json",
     "aws-codepipeline-pipeline.json",
     "aws-codepipeline-webhook.json",
     "aws-cognito-identitypool.json",
@@ -959,6 +1043,20 @@ cached: list[str] = [
     "aws-datasync-locations3.json",
     "aws-datasync-locationsmb.json",
     "aws-datasync-task.json",
+    "aws-datazone-datasource.json",
+    "aws-datazone-domainunit.json",
+    "aws-datazone-environment.json",
+    "aws-datazone-environmentactions.json",
+    "aws-datazone-environmentblueprintconfiguration.json",
+    "aws-datazone-environmentprofile.json",
+    "aws-datazone-formtype.json",
+    "aws-datazone-groupprofile.json",
+    "aws-datazone-owner.json",
+    "aws-datazone-policygrant.json",
+    "aws-datazone-project.json",
+    "aws-datazone-projectmembership.json",
+    "aws-datazone-subscriptiontarget.json",
+    "aws-datazone-userprofile.json",
     "aws-dlm-lifecyclepolicy.json",
     "aws-dms-datamigration.json",
     "aws-dms-dataprovider.json",
@@ -989,12 +1087,16 @@ cached: list[str] = [
     "aws-ec2-ipampoolcidr.json",
     "aws-ec2-ipamresourcediscovery.json",
     "aws-ec2-ipamresourcediscoveryassociation.json",
-    "aws-ec2-ipamscope.json",
+    "aws-ec2-ippoolroutetableassociation.json",
     "aws-ec2-keypair.json",
     "aws-ec2-launchtemplate.json",
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
+    "aws-ec2-networkinsightsaccessscope.json",
+    "aws-ec2-networkinsightsaccessscopeanalysis.json",
+    "aws-ec2-networkinsightsanalysis.json",
+    "aws-ec2-networkinsightspath.json",
     "aws-ec2-networkinterface.json",
     "aws-ec2-networkinterfaceattachment.json",
     "aws-ec2-networkperformancemetricsubscription.json",
@@ -1014,10 +1116,14 @@ cached: list[str] = [
     "aws-ec2-subnetroutetableassociation.json",
     "aws-ec2-trafficmirrorfilter.json",
     "aws-ec2-trafficmirrorfilterrule.json",
+    "aws-ec2-trafficmirrorsession.json",
     "aws-ec2-trafficmirrortarget.json",
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
+    "aws-ec2-transitgatewayconnectpeer.json",
+    "aws-ec2-transitgatewaymeteringpolicy.json",
+    "aws-ec2-transitgatewaymeteringpolicyentry.json",
     "aws-ec2-transitgatewaymulticastdomain.json",
     "aws-ec2-transitgatewaymulticastdomainassociation.json",
     "aws-ec2-transitgatewaymulticastgroupmember.json",
@@ -1035,17 +1141,20 @@ cached: list[str] = [
     "aws-ec2-vpcblockpublicaccessoptions.json",
     "aws-ec2-vpccidrblock.json",
     "aws-ec2-vpcdhcpoptionsassociation.json",
+    "aws-ec2-vpcencryptioncontrol.json",
     "aws-ec2-vpcendpoint.json",
     "aws-ec2-vpcendpointconnectionnotification.json",
     "aws-ec2-vpcendpointservice.json",
     "aws-ec2-vpcendpointservicepermissions.json",
     "aws-ec2-vpcgatewayattachment.json",
     "aws-ec2-vpcpeeringconnection.json",
+    "aws-ec2-vpnconcentrator.json",
     "aws-ec2-vpnconnection.json",
     "aws-ec2-vpnconnectionroute.json",
     "aws-ec2-vpngateway.json",
     "aws-ec2-vpngatewayroutepropagation.json",
     "aws-ecr-pullthroughcacherule.json",
+    "aws-ecr-pulltimeupdateexclusion.json",
     "aws-ecr-registrypolicy.json",
     "aws-ecr-registryscanningconfiguration.json",
     "aws-ecr-replicationconfiguration.json",
@@ -1054,6 +1163,7 @@ cached: list[str] = [
     "aws-ecs-capacityprovider.json",
     "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
+    "aws-ecs-expressgatewayservice.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
     "aws-ecs-taskdefinition.json",
@@ -1063,10 +1173,10 @@ cached: list[str] = [
     "aws-efs-mounttarget.json",
     "aws-eks-accessentry.json",
     "aws-eks-addon.json",
+    "aws-eks-capability.json",
     "aws-eks-cluster.json",
     "aws-eks-fargateprofile.json",
     "aws-eks-identityproviderconfig.json",
-    "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
     "aws-elasticache-globalreplicationgroup.json",
@@ -1075,6 +1185,7 @@ cached: list[str] = [
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
     "aws-elasticache-serverlesscache.json",
+    "aws-elasticache-subnetgroup.json",
     "aws-elasticache-user.json",
     "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
@@ -1094,6 +1205,7 @@ cached: list[str] = [
     "aws-emr-studio.json",
     "aws-emr-studiosessionmapping.json",
     "aws-emrcontainers-virtualcluster.json",
+    "aws-emrserverless-application.json",
     "aws-events-apidestination.json",
     "aws-events-archive.json",
     "aws-events-connection.json",
@@ -1104,6 +1216,8 @@ cached: list[str] = [
     "aws-eventschemas-registry.json",
     "aws-eventschemas-registrypolicy.json",
     "aws-eventschemas-schema.json",
+    "aws-fis-experimenttemplate.json",
+    "aws-fis-targetaccountconfiguration.json",
     "aws-fms-notificationchannel.json",
     "aws-fms-policy.json",
     "aws-fms-resourceset.json",
@@ -1139,7 +1253,9 @@ cached: list[str] = [
     "aws-guardduty-master.json",
     "aws-guardduty-member.json",
     "aws-guardduty-publishingdestination.json",
+    "aws-guardduty-threatentityset.json",
     "aws-guardduty-threatintelset.json",
+    "aws-guardduty-trustedentityset.json",
     "aws-iam-group.json",
     "aws-iam-grouppolicy.json",
     "aws-iam-instanceprofile.json",
@@ -1159,7 +1275,6 @@ cached: list[str] = [
     "aws-imagebuilder-component.json",
     "aws-imagebuilder-containerrecipe.json",
     "aws-imagebuilder-distributionconfiguration.json",
-    "aws-imagebuilder-image.json",
     "aws-imagebuilder-imagepipeline.json",
     "aws-imagebuilder-imagerecipe.json",
     "aws-imagebuilder-infrastructureconfiguration.json",
@@ -1169,6 +1284,9 @@ cached: list[str] = [
     "aws-inspectorv2-filter.json",
     "aws-internetmonitor-monitor.json",
     "aws-iot-thingprincipalattachment.json",
+    "aws-kafkaconnect-connector.json",
+    "aws-kafkaconnect-customplugin.json",
+    "aws-kafkaconnect-workerconfiguration.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
     "aws-kinesis-streamconsumer.json",
@@ -1185,12 +1303,9 @@ cached: list[str] = [
     "aws-lakeformation-tag.json",
     "aws-lakeformation-tagassociation.json",
     "aws-lambda-alias.json",
-    "aws-lambda-eventinvokeconfig.json",
-    "aws-lambda-eventsourcemapping.json",
-    "aws-lambda-function.json",
     "aws-lambda-layerversion.json",
+    "aws-lambda-layerversionpermission.json",
     "aws-lambda-permission.json",
-    "aws-lambda-version.json",
     "aws-launchwizard-deployment.json",
     "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
@@ -1213,6 +1328,7 @@ cached: list[str] = [
     "aws-mwaa-environment.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
+    "aws-networkfirewall-loggingconfiguration.json",
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
     "aws-networkfirewall-vpcendpointassociation.json",
@@ -1240,6 +1356,7 @@ cached: list[str] = [
     "aws-opensearchserverless-securityconfig.json",
     "aws-opensearchserverless-securitypolicy.json",
     "aws-opensearchserverless-vpcendpoint.json",
+    "aws-opensearchservice-application.json",
     "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
@@ -1248,7 +1365,6 @@ cached: list[str] = [
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
-    "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
     "aws-pcaconnectorad-connector.json",
     "aws-pcaconnectorad-directoryregistration.json",
@@ -1280,6 +1396,7 @@ cached: list[str] = [
     "aws-rds-dbproxytargetgroup.json",
     "aws-rds-dbsecuritygroup.json",
     "aws-rds-dbsecuritygroupingress.json",
+    "aws-rds-dbshardgroup.json",
     "aws-rds-dbsubnetgroup.json",
     "aws-rds-eventsubscription.json",
     "aws-rds-globalcluster.json",
@@ -1308,6 +1425,7 @@ cached: list[str] = [
     "aws-rolesanywhere-trustanchor.json",
     "aws-route53-cidrcollection.json",
     "aws-route53-dnssec.json",
+    "aws-route53-healthcheck.json",
     "aws-route53-hostedzone.json",
     "aws-route53-keysigningkey.json",
     "aws-route53-recordset.json",
@@ -1318,10 +1436,13 @@ cached: list[str] = [
     "aws-route53resolver-firewalldomainlist.json",
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
+    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverdnssecconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
+    "aws-route53resolver-resolverrule.json",
+    "aws-route53resolver-resolverruleassociation.json",
     "aws-rum-appmonitor.json",
     "aws-s3-accessgrant.json",
     "aws-s3-accessgrantsinstance.json",
@@ -1334,8 +1455,10 @@ cached: list[str] = [
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
     "aws-s3tables-namespace.json",
+    "aws-s3tables-table.json",
     "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
+    "aws-s3tables-tablepolicy.json",
     "aws-sagemaker-appimageconfig.json",
     "aws-sagemaker-domain.json",
     "aws-sagemaker-featuregroup.json",
@@ -1346,7 +1469,7 @@ cached: list[str] = [
     "aws-sagemaker-modelpackage.json",
     "aws-sagemaker-modelpackagegroup.json",
     "aws-sagemaker-pipeline.json",
-    "aws-sagemaker-space.json",
+    "aws-sagemaker-processingjob.json",
     "aws-sagemaker-studiolifecycleconfig.json",
     "aws-sagemaker-userprofile.json",
     "aws-scheduler-schedule.json",
@@ -1369,12 +1492,15 @@ cached: list[str] = [
     "aws-servicecatalog-launchnotificationconstraint.json",
     "aws-servicecatalog-launchroleconstraint.json",
     "aws-servicecatalog-launchtemplateconstraint.json",
+    "aws-servicecatalog-portfolioprincipalassociation.json",
+    "aws-servicecatalog-portfolioproductassociation.json",
     "aws-servicecatalog-portfolioshare.json",
     "aws-servicecatalog-resourceupdateconstraint.json",
     "aws-servicecatalog-serviceaction.json",
     "aws-servicecatalog-serviceactionassociation.json",
     "aws-servicecatalog-stacksetconstraint.json",
     "aws-servicecatalog-tagoption.json",
+    "aws-servicecatalog-tagoptionassociation.json",
     "aws-servicecatalogappregistry-application.json",
     "aws-servicecatalogappregistry-attributegroup.json",
     "aws-servicecatalogappregistry-attributegroupassociation.json",
@@ -1384,10 +1510,33 @@ cached: list[str] = [
     "aws-servicediscovery-privatednsnamespace.json",
     "aws-servicediscovery-publicdnsnamespace.json",
     "aws-servicediscovery-service.json",
+    "aws-ses-configurationset.json",
+    "aws-ses-configurationseteventdestination.json",
+    "aws-ses-contactlist.json",
+    "aws-ses-dedicatedippool.json",
+    "aws-ses-emailidentity.json",
+    "aws-ses-mailmanageraddoninstance.json",
+    "aws-ses-mailmanageraddonsubscription.json",
+    "aws-ses-mailmanageraddresslist.json",
+    "aws-ses-mailmanagerarchive.json",
+    "aws-ses-mailmanageringresspoint.json",
+    "aws-ses-mailmanagerrelay.json",
+    "aws-ses-mailmanagerruleset.json",
+    "aws-ses-mailmanagertrafficpolicy.json",
+    "aws-ses-multiregionendpoint.json",
+    "aws-ses-template.json",
+    "aws-ses-vdmattributes.json",
     "aws-shield-drtaccess.json",
     "aws-shield-proactiveengagement.json",
     "aws-shield-protection.json",
     "aws-shield-protectiongroup.json",
+    "aws-smsvoice-configurationset.json",
+    "aws-smsvoice-optoutlist.json",
+    "aws-smsvoice-phonenumber.json",
+    "aws-smsvoice-pool.json",
+    "aws-smsvoice-protectconfiguration.json",
+    "aws-smsvoice-resourcepolicy.json",
+    "aws-smsvoice-senderid.json",
     "aws-sns-subscription.json",
     "aws-sns-topic.json",
     "aws-sns-topicinlinepolicy.json",
@@ -1429,6 +1578,7 @@ cached: list[str] = [
     "aws-verifiedpermissions-policytemplate.json",
     "aws-vpclattice-accesslogsubscription.json",
     "aws-vpclattice-authpolicy.json",
+    "aws-vpclattice-domainverification.json",
     "aws-vpclattice-listener.json",
     "aws-vpclattice-resourcepolicy.json",
     "aws-vpclattice-rule.json",
